@@ -43,4 +43,17 @@
 #'   \item{LPA}{fourth compositional variable}
 #'   \item{SB}{fifth compositional variable}
 #' }
-"sbp"
\ No newline at end of file
+"sbp"
+
+#' multilevelcoda Simulation Study results
+#'
+#' A list of 4 components
+#'
+#' @format A list with 5 columns and 4 rows.
+#' \describe{
+#'   \item{brmcoda_tab}{Simulation results for brmcoda() for tables}
+#'   \item{sub_tab}{Simulation results for substitution() for tables}
+#'   \item{brmcoda_plot}{Simulation results for brmcoda() for graphs}
+#'   \item{sub_plot}{Simulation results for substitution() for graphs}
+#' }
+"sim"
\ No newline at end of file
