@@ -28,8 +28,8 @@ cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
 
 suppressWarnings(
   m <- brmcoda(complr = cilr,
-               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
-                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
+               formula = Stress ~ bz1_1 + bz2_1 + bz3_1 + bz4_1 +
+                 wz1_1 + wz2_1 + wz3_1 + wz4_1 + Female + (1 | ID),
                chain = 1, iter = 500, seed = 123,
                backend = backend))
 foreach::registerDoSEQ()
